Struct jsonnet::JsonVal
[−]
[src]
pub struct JsonVal<'a> { /* fields omitted */ }Rust wrapper for borrowed libjsonnet JSON values.
See JsonValue for the owned version.
Methods
impl<'a> JsonVal<'a>[src]
pub unsafe fn from_ptr(vm: &'a JsonnetVm, p: *const JsonnetJsonValue) -> Self[src]
Construct a JsonVal from a pointer returned from a
low-level jsonnet C function.
Safety
It is up to the caller to ensure that p was indeed allocated
by vm.
pub fn as_ptr(&self) -> *const JsonnetJsonValue[src]
Returns the inner pointer to this jsonnet value.
The returned pointer will be valid for as long as self is.
pub fn as_str(&self) -> Option<&str>[src]
Returns the value, if it is a string.
pub fn as_num(&self) -> Option<f64>[src]
Returns the value, if it is a number.
pub fn as_bool(&self) -> Option<bool>[src]
Returns the value, if it is a bool.
pub fn as_null(&self) -> Option<()>[src]
Returns Some(()) if the value is null.